@@ -255,7 +255,7 @@ void ReliablePostFileTask::onPostFileTaskFinished(bool result)
     error_string_ = task_->errorString();
     error_ = task_->error();
 
-    if (http_error_code_ == 442) {
+    if (http_error_code_ == 442 || http_error_code_ == 443) {
         emit finished(false);
         return;
     }
@@ -439,6 +439,7 @@ void PostFileTask::sendRequest()
         setContentRangeHeader(&request);
     }
 
+    request.setTransferTimeout(0);
     reply_ = getQNAM()->post(request, multipart);
 
     connect(reply_, SIGNAL(sslErrors(const QList<QSslError>&)),
