@@ -105,13 +105,13 @@ QString translateSyncErrorCode(const int error_code)
             break;
 #endif
         case SYNC_ERROR_ID_LIBRARY_TOO_LARGE:
-            error_str = QObject::tr("Library is too large to sync.");
+            error_str = QObject::tr("Library cannot be synced since it has too many files.");
             break;
         case SYNC_ERROR_ID_DEL_CONFIRMATION_PENDING:
             error_str = QObject::tr("Waiting for confirmation to delete files");
             break;
         case SYNC_ERROR_ID_TOO_MANY_FILES:
-            error_str = QObject::tr("Too many files in library");
+            error_str = QObject::tr("Files cannot be uploaded to this library due to file number limit settings.");
             break;
         case SYNC_ERROR_ID_CHECKOUT_FILE:
             error_str = QObject::tr("Failed to download file. Please check disk space or folder permissions");
@@ -119,6 +119,9 @@ QString translateSyncErrorCode(const int error_code)
         case SYNC_ERROR_ID_BLOCK_MISSING:
             error_str = QObject::tr("Failed to upload file blocks. Please check network or firewall");
             break;
+        case SYNC_ERROR_ID_CASE_CONFLICT:
+            error_str = QObject::tr("Path has character case conflict with existing file or folder. Will not be downloaded");
+            break;
         default:
             qWarning("Unknown sync error");
     }
